@@ -1,9 +1,10 @@
 # -*- coding: utf-8 -*-
 
-from tornadoes.models import BulkList
+import json
 
-from six.moves.urllib.parse import urlencode
-from tornado.escape import json_encode, json_decode
+from models import BulkList
+
+from urllib import urlencode
 from tornado.ioloop import IOLoop
 from tornado.httpclient import AsyncHTTPClient, HTTPRequest
 from tornado.concurrent import return_future
@@ -11,13 +12,13 @@ from tornado.concurrent import return_future
 
 class ESConnection(object):
 
-    def __init__(self, host='localhost', port='9200', io_loop=None, protocol='http'):
+    def __init__(self, host='localhost', port='9200', io_loop=None):
         self.io_loop = io_loop or IOLoop.instance()
-        self.url = "%(protocol)s://%(host)s:%(port)s" % {"protocol": protocol, "host": host, "port": port}
+        self.url = "http://%(host)s:%(port)s" % {"host": host, "port": port}
         self.bulk = BulkList()
         self.client = AsyncHTTPClient(self.io_loop)
-        self.httprequest_kwargs = {}     # extra kwargs passed to tornado's HTTPRequest class
-                                         # e.g. request_timeout
+        self.httprequest_kwargs = {}     #extra kwargs passed to tornado's HTTPRequest class
+                                         #e.g. request_timeout
 
     def create_path(self, method, **kwargs):
         index = kwargs.get('index', '_all')
@@ -46,11 +47,7 @@ class ESConnection(object):
     @return_future
     def search(self, callback, **kwargs):
         path = self.create_path("search", **kwargs)
-        source = json_encode(kwargs.get('source', {
-            "query": {
-                "match_all": {}
-            }
-        }))
+        source = json.dumps(kwargs.get('source', {"query": {"query_string": {"query": "*"}}}))
         self.post_by_path(path, callback, source)
 
     def multi_search(self, index, source):
@@ -75,16 +72,16 @@ class ESConnection(object):
         self.client.fetch(url, callback, **self.httprequest_kwargs)
 
     @return_future
-    def get(self, index, type, uid, callback, parameters=None):
+    def get(self, index, type, uid, callback):
         def to_dict_callback(response):
-            source = json_decode(response.body)
+            source = json.loads(response.body).get('_source', {})
             callback(source)
-        self.request_document(index, type, uid, callback=to_dict_callback, parameters=parameters)
+        self.request_document(index, type, uid, callback=to_dict_callback)
 
     @return_future
     def put(self, index, type, uid, contents, parameters=None, callback=None):
         self.request_document(
-            index, type, uid, "PUT", body=json_encode(contents),
+            index, type, uid, "PUT", body=json.dumps(contents),
             parameters=parameters, callback=callback)
 
     @return_future
@@ -104,7 +101,7 @@ class ESConnection(object):
             path += '?{}'.format(urlencode(parameters or {}))
 
         if source:
-            source = json_encode(source['query'])
+            source = json.dumps(source)
 
         self.post_by_path(path=path, callback=callback, source=source)
 
